==> openGion6.3.8.5_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF09S.sql <==
/****************************************************************************/
/* GF09 ( ｼｰｹﾝｽ定義 )                                                       */
/*                                                                          */
/* Created : 2015/09/17 15:31:10                                            */
/****************************************************************************/
CREATE TABLE GF09 (
   SYSTEM_ID    VARCHAR2 ( 10 )                         NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR2 (  1 )                         NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , SEQNAME      VARCHAR2 ( 50 )                         NOT NULL            /*  30 ｼｰｹﾝｽ名      */
 , INCREBY      NUMBER   (  9 )     DEFAULT 1           NOT NULL            /*  40 ｲﾝｸﾘﾒﾝﾄ      */
 , STARTVAL     NUMBER   (  9 )     DEFAULT 1           NOT NULL            /*  50 開始値       */
 , MINVAL       NUMBER   (  9 )     DEFAULT 1           NOT NULL            /*  60 最小値       */
 , MAXVAL       NUMBER              DEFAULT 999999999   NOT NULL            /*  70 最大値       */
 , FGCYCLE      VARCHAR2 (  1 )     DEFAULT '1'         NOT NULL            /*  80 ｻｲｸﾙﾌﾗｸﾞ     */
 , SUCACHE      NUMBER   (  7 )     DEFAULT 0           NOT NULL            /*  90 ｷｬｯｼｭ数      */
 , LAST_NUMBER  NUMBER                                                      /* 100 最終値       */
 , TABLE_NAME   VARCHAR2 ( 50 )                                             /* 110 ﾃｰﾌﾞﾙ名      */
 , CLM          VARCHAR2 ( 30 )                                             /* 120 項目         */
 , UNIQ         NUMBER   (  9 )     DEFAULT 0           NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (  1 )     DEFAULT '1'         NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 ( 14 )                                             /* 820 登録日時     */
 , PGSET        VARCHAR2 ( 10 )                                             /* 830 作成PG       */
 , PGPSET       VARCHAR2 ( 10 )                                             /* 840 作成親PG     */
 , USRSET       VARCHAR2 ( 10 )                                             /* 850 作成社員     */
 , DYUPD        VARCHAR2 ( 14 )                                             /* 860 更新日時     */
 , PGUPD        VARCHAR2 ( 10 )                                             /* 870 更新PG       */
 , PGPUPD       VARCHAR2 ( 10 )                                             /* 880 更新親PG     */
 , USRUPD       VARCHAR2 ( 10 )                                             /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );

CREATE SEQUENCE GF09S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF09T00 
  BEFORE INSERT ON GF09
  FOR EACH ROW 
  BEGIN 
    SELECT GF09S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion6.4.0.0_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF09S.sql <==
/****************************************************************************/
/* GF09 ( ｼｰｹﾝｽ定義 )                                                       */
/*                                                                          */
/* Created : 2015/11/16 16:20:03                                            */
/****************************************************************************/
CREATE TABLE GF09 (
   SYSTEM_ID    VARCHAR2 ( 10 )                         NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR2 (  1 )                         NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , SEQNAME      VARCHAR2 ( 50 )                         NOT NULL            /*  30 ｼｰｹﾝｽ名      */
 , INCREBY      NUMBER   (  9 )     DEFAULT 1           NOT NULL            /*  40 ｲﾝｸﾘﾒﾝﾄ      */
 , STARTVAL     NUMBER   (  9 )     DEFAULT 1           NOT NULL            /*  50 開始値       */
 , MINVAL       NUMBER   (  9 )     DEFAULT 1           NOT NULL            /*  60 最小値       */
 , MAXVAL       NUMBER              DEFAULT 999999999   NOT NULL            /*  70 最大値       */
 , FGCYCLE      VARCHAR2 (  1 )     DEFAULT '1'         NOT NULL            /*  80 ｻｲｸﾙﾌﾗｸﾞ     */
 , SUCACHE      NUMBER   (  7 )     DEFAULT 0           NOT NULL            /*  90 ｷｬｯｼｭ数      */
 , LAST_NUMBER  NUMBER                                                      /* 100 最終値       */
 , TABLE_NAME   VARCHAR2 ( 50 )                                             /* 110 ﾃｰﾌﾞﾙ名      */
 , CLM          VARCHAR2 ( 30 )                                             /* 120 項目         */
 , UNIQ         NUMBER   (  9 )     DEFAULT 0           NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (  1 )     DEFAULT '1'         NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 ( 14 )                                             /* 820 登録日時     */
 , PGSET        VARCHAR2 ( 10 )                                             /* 830 作成PG       */
 , PGPSET       VARCHAR2 ( 10 )                                             /* 840 作成親PG     */
 , USRSET       VARCHAR2 ( 10 )                                             /* 850 作成社員     */
 , DYUPD        VARCHAR2 ( 14 )                                             /* 860 更新日時     */
 , PGUPD        VARCHAR2 ( 10 )                                             /* 870 更新PG       */
 , PGPUPD       VARCHAR2 ( 10 )                                             /* 880 更新親PG     */
 , USRUPD       VARCHAR2 ( 10 )                                             /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K );

CREATE SEQUENCE GF09S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF09T00 
  BEFORE INSERT ON GF09
  FOR EACH ROW 
  BEGIN 
    SELECT GF09S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
